==> haskell-dns-3.0.4-64-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-dns.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: dns
version: 3.0.4
id: dns-3.0.4-KHyUpfXWCHe2YovXNJzUBx
key: dns-3.0.4-KHyUpfXWCHe2YovXNJzUBx
license: BSD-3-Clause
maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
author: Kazu Yamamoto <kazu@iij.ad.jp>
synopsis: DNS library in Haskell
description:
    A thread-safe DNS library for both clients and servers written
    in pure Haskell.
category: Network
abi: c07c63d75b39781d6bd59d15c9c8aceb
exposed: True
exposed-modules:
    Network.DNS Network.DNS.Decode Network.DNS.Encode Network.DNS.IO
    Network.DNS.Lookup Network.DNS.LookupRaw Network.DNS.Resolver
    Network.DNS.Types Network.DNS.Utils
hidden-modules: Network.DNS.Decode.Internal Network.DNS.Imports
                Network.DNS.Memo Network.DNS.StateBinary Network.DNS.Transport
                Network.DNS.Types.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/dns-3.0.4
library-dirs: /usr/lib/ghc-8.6.5/site-local/dns-3.0.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/dns-3.0.4
hs-libraries: HSdns-3.0.4-KHyUpfXWCHe2YovXNJzUBx
depends:
    async-2.2.1-GYH0rb5jjEHH7NChV9fWYh
    attoparsec-0.13.2.2-L0PhfJn0b3D3Qcx7KDBMXo
    auto-update-0.1.4.1-H02SxzDXmGPGYG55qTZ7dl base-4.12.0.0
    base64-bytestring-1.0.0.2-9hYbO3I2I9012gU046eVdX binary-0.8.6.0
    bytestring-0.10.8.2 containers-0.6.0.1
    cryptonite-0.26-5pCtI3fv84M4lNt7lObUcf
    iproute-1.7.7-FRlXPwxid8JMOv62fp4zU mtl-2.2.2
    network-2.8.0.0-A0G1UJzDIGiEvzFah0DnI2
    psqueues-0.2.7.1-5NlnSAVz7shBxXq5J2oBXe
    safe-0.3.17-43oyx4B630gDZMbTh3Ttji time-1.8.0.2
haddock-interfaces: /usr/share/doc/haskell-dns/html/dns.haddock
haddock-html: /usr/share/doc/haskell-dns/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-dns-3.0.4-65-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-dns.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: dns
version: 3.0.4
id: dns-3.0.4-9HvTKYkJANz8jE0rZtT7jd
key: dns-3.0.4-9HvTKYkJANz8jE0rZtT7jd
license: BSD-3-Clause
maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
author: Kazu Yamamoto <kazu@iij.ad.jp>
synopsis: DNS library in Haskell
description:
    A thread-safe DNS library for both clients and servers written
    in pure Haskell.
category: Network
abi: b1ca51450bb4b51875777b814d8bb2c0
exposed: True
exposed-modules:
    Network.DNS Network.DNS.Decode Network.DNS.Encode Network.DNS.IO
    Network.DNS.Lookup Network.DNS.LookupRaw Network.DNS.Resolver
    Network.DNS.Types Network.DNS.Utils
hidden-modules: Network.DNS.Decode.Internal Network.DNS.Imports
                Network.DNS.Memo Network.DNS.StateBinary Network.DNS.Transport
                Network.DNS.Types.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/dns-3.0.4
library-dirs: /usr/lib/ghc-8.6.5/site-local/dns-3.0.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/dns-3.0.4
hs-libraries: HSdns-3.0.4-9HvTKYkJANz8jE0rZtT7jd
depends:
    async-2.2.1-GYH0rb5jjEHH7NChV9fWYh
    attoparsec-0.13.2.2-WGDHRY8MTWGzoRjbN9EJO
    auto-update-0.1.4.1-H02SxzDXmGPGYG55qTZ7dl base-4.12.0.0
    base64-bytestring-1.0.0.2-11TO9fSEmuqDlOPx6IouNl binary-0.8.6.0
    bytestring-0.10.8.2 containers-0.6.0.1
    cryptonite-0.26-5pCtI3fv84M4lNt7lObUcf
    iproute-1.7.7-KFJ8416tbVxDdidBS7bEEV mtl-2.2.2
    network-2.8.0.0-xbHtkcSHJTFxVBp7aTame
    psqueues-0.2.7.1-20192jcFAWcCTlUxVQ5qjW
    safe-0.3.17-43oyx4B630gDZMbTh3Ttji time-1.8.0.2
haddock-interfaces: /usr/share/doc/haskell-dns/html/dns.haddock
haddock-html: /usr/share/doc/haskell-dns/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
